@@ -13,15 +13,24 @@
  *       - initial API and implementation
  *******************************************************************************/
 
-#define VALUE_MAX 16
+enum { CLOCK, REGULATOR, SENSOR, GPIO };
 
-WINDOW windows[TOTAL_FEATURE_WINS];
+struct display_ops {
+	int (*display)(bool refresh);
+	int (*select)(void);
+	int (*find)(const char *);
+	int (*selectf)(void);
+};
 
-#define PT_COLOR_DEFAULT    1
-#define PT_COLOR_HEADER_BAR 2
-#define PT_COLOR_ERROR      3
-#define PT_COLOR_RED        4
-#define PT_COLOR_YELLOW     5
-#define PT_COLOR_GREEN      6
-#define PT_COLOR_BRIGHT     7
-#define PT_COLOR_BLUE       8
+extern int display_print_line(int window, int line, char *str,
+			      int bold, void *data);
+
+extern int display_refresh_pad(int window);
+extern int display_reset_cursor(int window);
+extern void *display_get_row_data(int window);
+
+extern int display_init(int wdefault);
+extern int display_register(int win, struct display_ops *ops);
+extern int display_column_name(const char *line);
+
+#define NAME_MAX 255
